@@ -21,7 +21,7 @@ from zipfile import ZIP_DEFLATED, ZIP_STORED, PyZipFile, ZipFile, ZipInfo
 
 from setuptools import Distribution
 
-from cx_Freeze._compat import IS_MACOS, IS_MINGW, IS_WINDOWS
+from cx_Freeze._compat import IS_MACOS, IS_MINGW, IS_WINDOWS, PYTHON_VERSION
 from cx_Freeze.common import get_resource_file_path, process_path_specs
 from cx_Freeze.exception import FileError, OptionError
 from cx_Freeze.executable import Executable
@@ -372,6 +372,9 @@ class Freezer:
         bin_path = [
             sysconfig.get_config_var("LIBDIR"),
             sysconfig.get_config_var("DESTLIB"),
+            Path(  # uv python
+                sys.base_prefix, getattr(sys, "platlibdir", "lib")
+            ),
         ]
         return self._validate_bin_path(bin_path)
 
@@ -572,7 +575,7 @@ class Freezer:
         invalid = sorted(zip_include_packages & zip_exclude_packages)
         if invalid:
             msg = (
-                f"package{'s' if len(invalid)>1 else ''} "
+                f"package{'s' if len(invalid) > 1 else ''} "
                 f"{', '.join(invalid)!r} "
                 "cannot be both included and excluded from zip file"
             )
@@ -789,6 +792,7 @@ class Freezer:
 
         # do any platform-specific post-Freeze work
         self._post_freeze_hook()
+        self.finder.cleanup()
 
     def print_report(self) -> None:
         """Display report:
@@ -1016,7 +1020,7 @@ class WinFreezer(Freezer, PEParser):
         else:
             names = [
                 f"python{sys.version_info[0]}.dll",
-                f"python{sys.version_info[0]}{sys.version_info[1]}.dll",
+                f"python{PYTHON_VERSION.replace('.', '')}.dll",
             ]
         python_shared_libs: list[Path] = []
         for name in names:
@@ -1039,11 +1043,13 @@ class WinFreezer(Freezer, PEParser):
         # executable dependencies go into build root directory on windows
         # msys2 libpython depends on libgcc_s_seh and libwinpthread dlls
         # conda-forge python3x.dll depends on zlib.dll
-        finder = self.finder
+        lib_files = self.finder.lib_files
+        for path in map(Path, self.default_bin_includes):
+            lib_files.setdefault(path, path.name)
         for filename in self.get_dependent_files(source):
             path = filename.resolve()
-            if path not in finder.lib_files and self._should_copy_file(path):
-                finder.lib_files.setdefault(path, path.name)
+            if path not in lib_files and self._should_copy_file(path):
+                lib_files.setdefault(path, path.name)
                 self._get_top_dependencies(path)
 
     @cached_property
@@ -1331,9 +1337,9 @@ class LinuxFreezer(Freezer, ELFParser):
         ]
 
     def _get_top_dependencies(self, source: Path) -> None:  # noqa: ARG002
-        finder = self.finder
+        lib_files = self.finder.lib_files
         for path in map(Path, self.default_bin_includes):
-            finder.lib_files.setdefault(path, f"lib/{path.name}")
+            lib_files.setdefault(path, f"lib/{path.name}")
 
     def _post_copy_hook(
         self,
