@@ -7,9 +7,11 @@ import gettext
 import pycountry
 
 print("countries:", len(pycountry.countries))
-print("BR-FN", pycountry.subdivisions.get(code="BR-FN"))
+print("BR-FN", pycountry.subdivisions.get(code="BR-MG"))
 
-name = gettext.translation("iso3166", pycountry.LOCALES_DIR, languages=["pt"])
+name = gettext.translation(
+    "iso3166-1", pycountry.LOCALES_DIR, languages=["pt"]
+)
 name.install()
 _ = name.gettext
 print("Brazil ->", _("Brazil"))
