@@ -1,15 +1,14 @@
-"""
-A setup script to create a single executable.
-"""
+"""A setup script to create a single executable."""
 
 #
 # Run the build process by running the command 'python setup.py build'
 #
 # If everything works well you should find a subdirectory in the build
 # subdirectory that contains the files needed to run the script without Python
-from cx_Freeze import Executable, setup
 import sys
 
+from cx_Freeze import Executable, setup
+
 script = (
     "test_pydantic.py"
     if sys.version_info < (3, 10)
